@@ -30,9 +30,9 @@ class Inference(MaitaiClient):
 
     @classmethod
     def infer(cls, session_id, reference_id, intent, application_ref_name, completion_params: ChatCompletionParams, apply_corrections: bool, evaluation_enabled: bool, evaluate_callback: EvaluateCallback = None,
-              timeout=None, context_retrieval_enabled=False, context_query='', return_request=False, fallback_model=None) -> Iterable[InferenceStreamResponse]:
+              timeout=None, context_retrieval_enabled=False, context_query='', return_request=False, fallback_model=None, user_id: str = "") -> Iterable[InferenceStreamResponse]:
         chat_request: ChatCompletionRequest = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params, evaluate_callback,
-                                                                           context_retrieval_enabled, context_query, return_request, fallback_model)
+                                                                           context_retrieval_enabled, context_query, return_request, fallback_model, user_id)
         if evaluate_callback:
             q = ChunkQueue()
             cls.run_async(cls.send_inference_request_async(chat_request, chunk_queue=q, evaluation_callback=evaluate_callback))
@@ -42,9 +42,9 @@ class Inference(MaitaiClient):
 
     @classmethod
     async def infer_async(cls, session_id, reference_id, intent, application_ref_name, completion_params: ChatCompletionParams, apply_corrections: bool, evaluation_enabled: bool,
-                          evaluate_callback: EvaluateCallback = None, timeout=None, context_retrieval_enabled=False, context_query='', fallback_model=None) -> AsyncIterable[InferenceStreamResponse]:
+                          evaluate_callback: EvaluateCallback = None, timeout=None, context_retrieval_enabled=False, context_query='', fallback_model=None, user_id="") -> AsyncIterable[InferenceStreamResponse]:
         chat_request: ChatCompletionRequest = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params, evaluate_callback,
-                                                                           context_retrieval_enabled, context_query, fallback_model)
+                                                                           context_retrieval_enabled, context_query, fallback_model, user_id)
         q = AsyncChunkQueue()
         cls.run_async(cls.send_inference_request_async(chat_request, async_chunk_queue=q, evaluation_callback=evaluate_callback))
         return QueueIterable(q, timeout=timeout)
