@@ -94,6 +94,7 @@ class AsyncCompletions:
         self,
         *,
         # Maitai Arguments
+        user_id: str = "",
         session_id: Union[str, int] = None,
         reference_id: Union[str, int, None] = None,
         intent: str = None,
@@ -201,7 +202,7 @@ class AsyncCompletions:
             if isinstance(timeout, float) or isinstance(timeout, int):
                 response_timeout = timeout
             response = await maitai.Inference.infer_async(session_id, reference_id, intent, application_ref_name, completion_params, apply_corrections, evaluation_enabled, callback, timeout=response_timeout,
-                                                          context_retrieval_enabled=context_retrieval_enabled, context_query=context_query, fallback_model=fallback_model)
+                                                          context_retrieval_enabled=context_retrieval_enabled, context_query=context_query, fallback_model=fallback_model, user_id=user_id)
             if stream:
                 return _process_inference_stream_async(response)
             # ChatCompletion only
