@@ -35,7 +35,8 @@ class MaitaiClient:
             threading.Thread(target=run).start()
 
     @classmethod
-    def create_inference_request(cls, application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params: ChatCompletionParams, callback=None, context_retrieval_enabled=False, context_query=None, return_request=False, fallback_model=None):
+    def create_inference_request(cls, application_ref_name, session_id, reference_id, intent, apply_corrections, evaluation_enabled, completion_params: ChatCompletionParams, callback=None,
+                                 context_retrieval_enabled=False, context_query=None, return_request=False, fallback_model=None, user_id=""):
         infer_request: ChatCompletionRequest = ChatCompletionRequest()
         infer_request.application_ref_name = application_ref_name
         infer_request.reference_id = reference_id
@@ -50,4 +51,5 @@ class MaitaiClient:
         infer_request.context_query = context_query
         infer_request.return_request = return_request
         infer_request.fallback_model = fallback_model
+        infer_request.user_id = user_id
         return infer_request
